@@ -6,9 +6,7 @@ test_that("lat and lon columns are successfully found", {
   expect_true(names(googleway:::latitude_column(data.frame(latitude = c(1,2,3)), lat = NULL, "tests")) == "lat")
   expect_true(names(googleway:::latitude_column(data.frame(lats = c(1,2,3)), lat = NULL, "tests")) == "lat")
   expect_true(names(googleway:::latitude_column(data.frame(latitudes = c(1,2,3)), lat = NULL, "tests")) == "lat")
-
   expect_error(names(googleway:::latitude_column(data.frame(myLat = c(1,2,3)), lat = NULL, "tests")) == "lat")
-
   expect_true(names(googleway:::longitude_column(data.frame(lon = c(1,2,3)), lon = NULL, "tests")) == "lng")
   expect_true(names(googleway:::longitude_column(data.frame(longitude = c(1,2,3)), lon = NULL, "tests")) == "lng")
   expect_true(names(googleway:::longitude_column(data.frame(lons = c(1,2,3)), lon = NULL, "tests")) == "lng")
@@ -17,7 +15,6 @@ test_that("lat and lon columns are successfully found", {
   expect_true(names(googleway:::longitude_column(data.frame(lngs = c(1,2,3)), lon = NULL, "tests")) == "lng")
   expect_true(names(googleway:::longitude_column(data.frame(long = c(1,2,3)), lon = NULL, "tests")) == "lng")
   expect_true(names(googleway:::longitude_column(data.frame(longs = c(1,2,3)), lon = NULL, "tests")) == "lng")
-
   expect_error(names(googleway:::longitude_column(data.frame(myLon = c(1,2,3)), lon = NULL, "tests")) == "lat")
 
 })
@@ -60,10 +57,7 @@ test_that("latitude column is found", {
   )
 
   df <- data.frame(lat = c(1))
-  expect_silent(
-    googleway:::latitude_column(df, NULL, 'test')
-  )
-
+  expect_silent(googleway:::latitude_column(df, NULL, 'test'))
 })
 
 test_that("longitude column is found", {
@@ -80,10 +74,7 @@ test_that("longitude column is found", {
   )
 
   df <- data.frame(lon = c(1))
-  expect_silent(
-    googleway:::longitude_column(df, NULL, 'test')
-  )
-
+  expect_silent(googleway:::longitude_column(df, NULL, 'test'))
 })
 
 test_that("lat & lon are found", {
@@ -102,30 +93,19 @@ test_that("lat & lon return NA if error", {
 
   df <- data.frame(lat = 1, lats = 2)
 
-  expect_true(
-    is.na(googleway:::find_lat_column(names(df), "test", stopOnFailure = F))
-  )
+  expect_true(is.na(googleway:::find_lat_column(names(df), "test", stopOnFailure = F)))
 
   df <- data.frame(lon = 1, lons = 2)
 
-  expect_true(
-    is.na(googleway:::find_lon_column(names(df), "test", stopOnFailure = F))
-  )
-
+  expect_true(is.na(googleway:::find_lon_column(names(df), "test", stopOnFailure = F)))
 })
 
 test_that("URL method checks are correct", {
 
   myUrl <- "myurl"
   attr(myUrl, 'class') <- "url"
-  expect_true(
-    googleway:::urlCheck(myUrl) == "myurl"
-  )
-
-  expect_error(
-    googleway:::urlCheck(3)
-  )
-
+  expect_true(googleway:::urlCheck(myUrl) == "myurl")
+  expect_error(googleway:::urlCheck(3))
 })
 
 test_that("locations are valid", {
@@ -174,80 +154,41 @@ test_that("locations are valid", {
   num_fail <- c(-37, 144, -36, 146)
   lst_pass <- list(c(-37, 144))
 
-  expect_true(
-    googleway:::validateLocations(df_pass)[[1]] == "Melbourne"
-  )
-
-  expect_true(
-    googleway:::validateLocations(df_fail)[[1]] == "Melbourne"
-  )
-
-  expect_true(
-    googleway:::validateLocations(df_fail)[[2]] == "Sydney"
-  )
-
-  expect_true(
-    googleway:::validateLocations(vec_pass) == "Melbourne"
-  )
-  expect_true(
-    sum(googleway:::validateLocations(vec_fail) == c("Melbourne", "Sydney")) == 2
-  )
-
-  expect_true(
-    sum(googleway:::validateLocations(vec_fail) == c("Melbourne", "Sydney")) == 2
-  )
-
+  expect_true(googleway:::validateLocations(df_pass)[[1]] == "Melbourne")
+  expect_true(googleway:::validateLocations(df_fail)[[1]] == "Melbourne")
+  expect_true(googleway:::validateLocations(df_fail)[[2]] == "Sydney")
+  expect_true(googleway:::validateLocations(vec_pass) == "Melbourne")
+  expect_true(sum(googleway:::validateLocations(vec_fail) == c("Melbourne", "Sydney")) == 2)
+  expect_true(sum(googleway:::validateLocations(vec_fail) == c("Melbourne", "Sydney")) == 2)
 
   ## diretions lat/lon columns permitted
   df_pass <- googleway::tram_stops[1, c("stop_lat", "stop_lon")]
-
-  expect_true(
-    sum(googleway:::validateLocation(df_pass) == c(-37.8090, 144.9731)) == 2
-  )
-
-
+  expect_true(sum(googleway:::validateLocation(df_pass) == c(-37.8090, 144.9731)) == 2)
   ## Other types are returned as-is
-  expect_true(
-    googleway:::validateLocation(T)
-  )
-
+  expect_true(googleway:::validateLocation(T))
 })
 
 test_that("address check works", {
-
   expect_error(
     googleway:::check_address(c("add 1", "add 2")),
     "address must be a string of length 1"
   )
-
 })
 
 
 test_that("avoid arg is valid", {
-
-  expect_true(
-    googleway:::validateAvoid("TOLLS") == "tolls"
-  )
-
+  expect_true(googleway:::validateAvoid("TOLLS") == "tolls")
 })
 
 test_that("bounds arg is valid", {
-
   bounds <- list(c(0,0), c(1,1))
-  expect_true(
-    googleway:::validateBounds(bounds) == "0,0|1,1"
-  )
-
+  expect_true(googleway:::validateBounds(bounds) == "0,0|1,1")
 })
 
 
 test_that("components arg is valid", {
-
   components <- data.frame(component = "country", value = "UK")
-
-  expect_true(
-    googleway:::validateComponents(components) == "country:uk"
-  )
+  expect_true(googleway:::validateComponents(components) == "country:uk")
 })
 
 
@@ -280,77 +221,46 @@ test_that("country components are valid", {
 })
 
 test_that("language arg validate", {
-
-  expect_true(
-    googleway:::validateLanguage("EN") == "en"
-  )
-
+  expect_true(googleway:::validateLanguage("EN") == "en")
 })
 
 test_that("heading arg validated", {
-
-  expect_true(
-    googleway:::validateHeading(23) == 23
-  )
-
+  expect_true(googleway:::validateHeading(23) == 23)
 })
 
 test_that("location_type arg validated", {
-
-  expect_true(
-    googleway:::validateLocationType("rooftop") == "ROOFTOP"
-  )
+  expect_true(googleway:::validateLocationType("rooftop") == "ROOFTOP")
 })
 
 
 test_that("page token arg is validated", {
-
-  expect_true(
-    googleway:::validatePageToken("mypagetoken") == "mypagetoken"
-  )
-
+  expect_true(googleway:::validatePageToken("mypagetoken") == "mypagetoken")
 })
 
 test_that("place type arg is validated", {
-
-  expect_true(
-    googleway:::validatePlaceType("restaurant") == "restaurant"
-  )
-
+  expect_true(googleway:::validatePlaceType("restaurant") == "restaurant")
 })
 
 test_that("price range arg is valid", {
-
-  expect_true(
-    all(googleway:::validatePriceRange(c(0, 4)) %in% c(0,4))
-  )
+  expect_true(all(googleway:::validatePriceRange(c(0, 4)) %in% c(0,4)))
 })
 
 
 test_that("region arg is valid", {
-
-  expect_true(
-    googleway:::validateRegion("EN") == "en"
-  )
+  expect_true(googleway:::validateRegion("EN") == "en")
 })
 
 test_that("result type arg is valid",{
-
   expect_true(
     googleway:::validateResultType("JSON") == "json"
   )
-
 })
 
 test_that("traffic model arg is valid", {
-
-  expect_true(
-    googleway:::validateTrafficModel(c("best guess")) == "best_guess"
-  )
+  expect_true(googleway:::validateTrafficModel(c("best guess")) == "best_guess")
 })
 
 test_that("transit routing preferences arg is valid", {
-
   expect_true(
     googleway:::validateTransitRoutingPreference("fewer_transfers", "transit") == "fewer_transfers"
   )
